import 'package:flutter/material.dart';
import 'package:slide_container/slide_container.dart';
import 'package:slide_container/slide_container_controller.dart';
import 'package:slide_container/widgets/slide_container_scroll_view.dart';

/// This example shows of the [SlideContainer] can be used in conjunction with a SingleChildScrollView.
///
/// See [SlideContainerScrollView].
class Page4 extends StatefulWidget {
  @override
  _State createState() => _State();
}

class _State extends State<Page4> {
  /// Don't forget to use the same [SlideContainerController] in the [SlideContainer] and in its
  /// nested [SlideContainerScrollView].
  final SlideContainerController controller = SlideContainerController();

  @override
  Widget build(BuildContext context) => SlideContainer(
        controller: controller,
        slideDirection: SlideContainerDirection.vertical,
        maxSlideDistance: MediaQuery.of(context).size.height * 0.2,
        child: SlideContainerScrollView(
          slideContainerController: controller,
          minTotalOverScrollToTriggerSlideContainer: 150,
          child: Container(
            height: MediaQuery.of(context).size.height * 1.5,
            alignment: Alignment.center,
            decoration: BoxDecoration(
              gradient: LinearGradient(
                begin: Alignment.topLeft,
                end: Alignment.bottomRight,
                colors: [
                  const Color(0xfffddb92),
                  const Color(0xffd1fdff),
                ],
              ),
              boxShadow: [
                const BoxShadow(
                  color: Color(0x90000000),
                  blurRadius: 10.0,
                  spreadRadius: 5.0,
                ),
              ],
            ),
            child: Column(
              children: <Widget>[
                Padding(padding: const EdgeInsets.only(top: 70)),
                Text(
                  "Over-scroll me! ↓↓↓",
                  style: TextStyle(fontSize: 26.0),
                ),
                Expanded(
                  child: Center(
                    child: Text(
                      "Scroll me!",
                      style: TextStyle(fontSize: 26.0),
                    ),
                  ),
                ),
                Text(
                  "Over-scroll me! ↑↑↑",
                  style: TextStyle(fontSize: 26.0),
                ),
                Padding(padding: const EdgeInsets.only(top: 70)),
              ],
            ),
          ),
        ),
      );
}
