import 'package:flutter/material.dart';
import 'package:slide_container/slide_container.dart';
import 'package:slide_container/slide_container_controller.dart';
import 'package:slide_container/widgets/close_page_slide_container.dart';
import 'package:slide_container/widgets/slide_container_scroll_view.dart';

/// Other example of the [SlideContainer] being used in conjunction with a SingleChildScrollView to pop the page.
///
/// See [SlideContainerScrollView] and [ClosePageSlideContainer].
class Page5 extends StatefulWidget {
  @override
  _State createState() => _State();
}

class _State extends State<Page5> {
  @override
  Widget build(BuildContext context) => Container(
        alignment: Alignment.center,
        child: RaisedButton(
          onPressed: () =>
              Navigator.of(context).push(_SlideContainerWithScrollViewPage()),
          child: Text("Click to show page"),
        ),
      );
}

class _SlideContainerWithScrollViewPage extends PopupRoute<Null> {
  @override
  Color get barrierColor => null;

  @override
  bool get barrierDismissible => false;

  @override
  bool get opaque => false;

  @override
  String get barrierLabel => "Close";

  @override
  Duration get transitionDuration => const Duration(microseconds: 1);

  @override
  Widget buildPage(_, __, ___) => _SlideContainerWithScrollView();
}

class _SlideContainerWithScrollView extends StatelessWidget {
  final SlideContainerController controller = SlideContainerController();

  @override
  Widget build(BuildContext context) => Scaffold(
        backgroundColor: Colors.transparent,
        body: ClosePageSlideContainer(
          controller: controller,
          child: SlideContainerScrollView(
            slideContainerController: controller,
            minTotalOverScrollToTriggerSlideContainer: 150,
            child: Container(
              height: MediaQuery.of(context).size.height * 1.5,
              alignment: Alignment.center,
              decoration: BoxDecoration(
                gradient: LinearGradient(
                  begin: Alignment.topLeft,
                  end: Alignment.bottomRight,
                  colors: [
                    const Color(0xfffddb92),
                    const Color(0xffd1fdff),
                  ],
                ),
                boxShadow: [
                  const BoxShadow(
                    color: Color(0x90000000),
                    blurRadius: 10.0,
                    spreadRadius: 5.0,
                  ),
                ],
              ),
              child: Column(
                children: <Widget>[
                  Padding(padding: const EdgeInsets.only(top: 70)),
                  Text(
                    "Over-scroll me to\n pop the page! ↓↓↓",
                    style: TextStyle(fontSize: 26.0),
                  ),
                  Expanded(
                    child: Center(
                      child: Text(
                        "Scroll me!",
                        style: TextStyle(fontSize: 26.0),
                      ),
                    ),
                  ),
                ],
              ),
            ),
          ),
        ),
      );
}
